==> core-react-0.8.0.tgz: package/es/Board/Board.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';

var Board = function Board(props) {
  var children = props.children,
      className = props.className,
      theme = props.theme,
      other = _objectWithoutProperties(props, ["children", "className", "theme"]);

  return React.createElement("div", _extends({
    className: cx("".concat("waui", "-board"), "".concat("waui", "-board_").concat(theme), className)
  }, other), children);
};

Board.propTypes = {
  children: PropTypes.any,
  className: PropTypes.string,

  /** The theme style of Board, default value is `classic` */
  theme: PropTypes.oneOf(['classic', 'simple'])
};
Board.defaultProps = {
  theme: 'classic'
};
export default Board;

==> core-react-0.8.2.tgz: package/es/Board/Board.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';

var Board = function Board(props) {
  var children = props.children,
      className = props.className,
      theme = props.theme,
      other = _objectWithoutProperties(props, ["children", "className", "theme"]);

  return (/*#__PURE__*/React.createElement("div", _extends({
      className: cx("".concat("waui", "-board"), "".concat("waui", "-board_").concat(theme), className)
    }, other), children)
  );
};

Board.propTypes = {
  children: PropTypes.any,
  className: PropTypes.string,

  /** The theme style of Board, default value is `classic` */
  theme: PropTypes.oneOf(['classic', 'simple'])
};
Board.defaultProps = {
  theme: 'classic'
};
export default Board;
